// ***************************************
//            Absolutelyautomation.com
//
//  PANEL MOUNT 7 SEGMENT DISPLAY  
//  WITH EMBEDDED ARDUINO
//  
//  Used as standalone temperature controller
//  with a 1-wire ds18b20 sensor
//
//****************************************


#include <SevenSeg.h> 
#include <DallasTemperature.h>
#include <OneWire.h> 

 
// Segments setup
int sega = 12;
int segb = 10;
int segc = 7;
int segd = 5;
int sege = 3;
int segf = 11;
int segg = 2;
int segp = 6;

// Commons setup
int digit1 = 13;
int digit2 = A0;
int digit3 = A1;

String dispvalue = "------";
char StrArray[4];

int FWMajorVersion=0;
int FWMinorVersion=1;


SevenSeg disp( sega, segb, segc, segd, sege, segf, segg );
const int numOfDigits = 3;
int digitPins[numOfDigits] = { digit1, digit2, digit3  };  

int firstboot;

String astring = "A00";    
String fstring = "F00";    


// pin for the sensor data wire
#define ONE_WIRE_BUS A3
// Instance oneWire to start communication with any OneWire device(not only Maxim/Dallas temperature)
OneWire oneWire(ONE_WIRE_BUS);
// Pass oneWire reference to Dallas Temperature. 
DallasTemperature sensors(&oneWire);

float  TempInC  ; // Float Variable temp in C
int    RoundTempInC  ; //Integer variable temp in C


String stringTemp = "  ";   

void setup() {                

  // Display setup
  
  pinMode(sega, OUTPUT);     
  pinMode(segb, OUTPUT);     
  pinMode(segc, OUTPUT);     
  pinMode(segd, OUTPUT);     
  pinMode(sege, OUTPUT);     
  pinMode(segf, OUTPUT);     
  pinMode(segg, OUTPUT);     
  pinMode(segp, OUTPUT);     
  
  pinMode(digit1, OUTPUT);     
  pinMode(digit2, OUTPUT);     
  pinMode(digit3, OUTPUT);     


  disp.setDPPin(segp);  
  //disp.setCommonCathode();
  disp.setCommonAnode();
  disp.setDigitPins( numOfDigits, digitPins );
  disp.setRefreshRate(300);
  disp.setTimer(1);  // Don't use with servo functions at the same time!
  //disp.setTimer(2);  // Don't use with tone() at the same time!
  disp.startTimer();   
 
 
 // One wire sensors
 sensors.begin();   
 
 // control Output
 pinMode(A4, OUTPUT);     
 
}

// infinite loop:
void loop() {
  if(!firstboot){
    disp.write("8.8.8.");
    delay(500);
    disp.write("");
    delay(500);
    fstring = "U"+String(FWMajorVersion,DEC)+"."+String(FWMinorVersion,DEC);        
    disp.write(fstring);// FW version = MajorVersion.MinorVersion
    delay(500);
    disp.write("");
    delay(500);    
    
    firstboot=1;    
  }
  
    
  sensors.requestTemperatures(); 
  //TempInC=sensors.getTempFByIndex(0);
  TempInC=sensors.getTempCByIndex(0);
   
  // comparation not very reliable with float numbers, use with care!!
  if( TempInC > 99.9 )
  {
    dtostrf(TempInC, 3, 0, StrArray);
  }
  else
  {
    dtostrf(TempInC, 4, 1, StrArray);
  }
  dispvalue = StrArray;
  

  // Simplistic control example
  // comparation not very reliable with float numbers, use with care!!
  if( TempInC > 33.0 )
  {
    digitalWrite(A4,HIGH);
  }
  else  
  {
    digitalWrite(A4,LOW);
  }
  
    
  // display refresh
  disp.write(dispvalue);

}

ISR(TIMER1_COMPA_vect)   {
  disp.interruptAction();
}



